@@ -125,6 +125,17 @@ def run_tests(scrypt, scrypt_mcf, scrypt_mcf_check, verbose=False, fast=False):
         print("  Invalid N value -1 accepted")
         fails += 1
 
+    i += 1
+    try:
+        scrypt(b'password', b'salt', N=1)
+    except ValueError:
+        if verbose:
+            print("Test %d successful!" % i)
+    else:
+        print("Test %d failed!" % i)
+        print("  Invalid N value 1 accepted")
+        fails += 1
+
     i += 1
     if (scrypt_mcf(b'password', b'salt', N=2) !=
             scrypt_mcf(b'password', b'salt', N=2)):
@@ -272,7 +283,7 @@ def run_tests(scrypt, scrypt_mcf, scrypt_mcf_check, verbose=False, fast=False):
 
     i += 1
     try:
-        scrypt_mcf(b'password', b'NaCl', N=2, r=0)
+        scrypt(b'password', b'NaCl', N=2, r=0)
     except ValueError:
         if verbose:
             print("Test %d successful!" % i)
